@@ -299,10 +299,10 @@ def _make_df_part(codes: list, q):
     q.put(df)
 
 
-def get_df(refresh: bool = False) -> pd.DataFrame:
+def make_today_eval_df(refresh: bool = False) -> pd.DataFrame:
     """ 멀티프로세싱을 사용하여 전체 종목의 eval 을 데이터프레임으로 만들어 반환
 
-    기본값으로 refresh 는 False 로 설정되어 당일자의 저장된 데이터프레임이 있으면 새로 생성하지 않고 DB를 이용한다.
+    기본값으로 refresh 는 False 로 설정되어 당일자의 저장된 데이터프레임이 있으면 새로 생성하지 않고 mongo DB를 이용한다.
 
     Args:
         refresh (bool): 저장된 db 자료를 이용하지 않고 강제로 리프레시하는 경우
