@@ -327,9 +327,9 @@ def growth(code: str) -> tuple:
     else:
         raise ValueError(f'Invalid code: {code}')
 
-    grwoth_dict = eval_growth(code)
+    growth_dict = eval_growth(code)
 
-    logger.debug(pprint.pformat(grwoth_dict, width=200))
+    logger.debug(pprint.pformat(growth_dict, width=200))
 
     def 매출액증가율평가(매출액증가율: tuple) -> int:
         # 매출액은 어떤경우에도 성장하는 기업이 좋다.매출이 20%씩 늘어나는 종목은 유망한 종목
@@ -341,25 +341,25 @@ def growth(code: str) -> tuple:
         if math.isnan(최근분기):
             최근분기 = 최근연도
 
-        p1 = 0
+        sp1 = 0
         if math.isnan(최근연도):
             pass
         elif 0 < 최근연도 and 0 < 최근분기:
             # 최근에 마이너스 성장이 아닌경우 MAX/10점 보너스
-            p1 += MAX / 10
+            sp1 += MAX / 10
             if 최근연도 < 최근분기:
                 # 최근에 이전보다 더 성장중이면 MAX/10점 보너스
-                p1 += MAX / 10
+                sp1 += MAX / 10
             # 나머지는 성장률 기반 점수 배정
-            p1 += MAX / 2 if 최근분기 > MAX else 최근분기 / 2
+            sp1 += MAX / 2 if 최근분기 > MAX else 최근분기 / 2
         elif 최근연도 <= 0 < 최근분기:
             # 직전에 마이너스였다가 최근에 회복된 경우 MAX/10점 보너스
-            p1 += MAX / 10
+            sp1 += MAX / 10
             # 나머지는 성장률 기반 점수 배정
-            p1 += MAX / 2 if 최근분기 > MAX else 최근분기 / 2
+            sp1 += MAX / 2 if 최근분기 > MAX else 최근분기 / 2
         else:
             # 최근 자료가 마이너스인 경우 마이너스만큼 점수를 차감한다.
-            p1 += -(MAX / 2) if 최근분기 < -MAX else 최근분기 / 2
+            sp1 += -(MAX / 2) if 최근분기 < -MAX else 최근분기 / 2
 
         # 평균매출액증가율 구하기
         d_values = [i for i in dict_y.values() if not math.isnan(i)]
@@ -368,20 +368,20 @@ def growth(code: str) -> tuple:
         평균매출액증가율 = float(numpy.mean(d_values))
         logger.info(f'평균 : {평균매출액증가율}')
 
-        p2 = 0
+        sp2 = 0
         if math.isnan(평균매출액증가율):
-            p2 += -(MAX/2)
+            sp2 += -(MAX/2)
         elif 평균매출액증가율 <= 0:
             # 평균매출액증가율이 마이너스인 경우 마이너스만큼 점수를 차감한다.
-            p2 += -(MAX / 2) if 평균매출액증가율 < -MAX else 평균매출액증가율 / 2
+            sp2 += -(MAX / 2) if 평균매출액증가율 < -MAX else 평균매출액증가율 / 2
         else:
-            p2 = MAX / 2 if 평균매출액증가율 > MAX else 평균매출액증가율 / 2
+            sp2 = MAX / 2 if 평균매출액증가율 > MAX else 평균매출액증가율 / 2
 
-        logger.info(f'매출액증가율평가 point : {p1 + p2}')
+        logger.info(f'매출액증가율평가 point : {sp1 + sp2}')
 
-        return int(p1 + p2)
+        return int(sp1 + sp2)
 
-    p1 = 매출액증가율평가(grwoth_dict['매출액증가율'])
+    p1 = 매출액증가율평가(growth_dict['매출액증가율'])
 
     def 영업이익률평가(영업이익률: dict) -> int:
         # 영업이익률은 기업의 경쟁력척도로 경쟁사에 비해 높으면 경제적해자를 갖춘셈
@@ -408,11 +408,6 @@ def growth(code: str) -> tuple:
         logger.info(f'영업이익률평가 point : {p}')
         return p
 
-    p2 = 영업이익률평가(grwoth_dict['영업이익률'])
+    p2 = 영업이익률평가(growth_dict['영업이익률'])
 
     return p1, p2
-
-
-
-
-
